@@ -5,7 +5,7 @@ use crate::{
         event_pump, CommandBlocking, CommandInfo, CommitComponent,
         Component, DrawableComponent, ExternalEditorComponent,
         HelpComponent, InspectCommitComponent, MsgComponent,
-        ResetComponent, StashMsgComponent,
+        ResetComponent, StashMsgComponent, TagCommitComponent,
     },
     input::{Input, InputEvent, InputState},
     keys,
@@ -18,8 +18,11 @@ use anyhow::{anyhow, Result};
 use asyncgit::{sync, AsyncNotification, CWD};
 use crossbeam_channel::Sender;
 use crossterm::event::{Event, KeyEvent};
-use std::path::PathBuf;
-use std::{cell::Cell, cell::RefCell, rc::Rc};
+use std::{
+    cell::{Cell, RefCell},
+    path::Path,
+    rc::Rc,
+};
 use tui::{
     backend::Backend,
     layout::{Constraint, Direction, Layout, Margin, Rect},
@@ -37,6 +40,7 @@ pub struct App {
     stashmsg_popup: StashMsgComponent,
     inspect_commit_popup: InspectCommitComponent,
     external_editor_popup: ExternalEditorComponent,
+    tag_commit_popup: TagCommitComponent,
     cmdbar: RefCell<CommandBar>,
     tab: usize,
     revlog: Revlog,
@@ -49,7 +53,7 @@ pub struct App {
 
     // "Flags"
     requires_redraw: Cell<bool>,
-    file_to_open: Option<Box<PathBuf>>,
+    file_to_open: Option<String>,
 }
 
 // public interface
@@ -82,6 +86,10 @@ impl App {
             external_editor_popup: ExternalEditorComponent::new(
                 theme.clone(),
             ),
+            tag_commit_popup: TagCommitComponent::new(
+                queue.clone(),
+                theme.clone(),
+            ),
             do_quit: false,
             cmdbar: RefCell::new(CommandBar::new(theme.clone())),
             help: HelpComponent::new(theme.clone()),
@@ -202,7 +210,7 @@ impl App {
                 let result = match self.file_to_open.take() {
                     Some(path) => {
                         ExternalEditorComponent::open_file_in_editor(
-                            &path,
+                            Path::new(&path),
                         )
                     }
                     None => self.commit.show_editor(),
@@ -293,6 +301,7 @@ impl App {
             stashmsg_popup,
             inspect_commit_popup,
             external_editor_popup,
+            tag_commit_popup,
             help,
             revlog,
             status_tab,
@@ -416,9 +425,12 @@ impl App {
                 self.stashmsg_popup.options(opts);
                 self.stashmsg_popup.show()?
             }
+            InternalEvent::TagCommit(id) => {
+                self.tag_commit_popup.open(id)?;
+            }
             InternalEvent::TabSwitch => self.set_tab(0)?,
-            InternalEvent::InspectCommit(id) => {
-                self.inspect_commit_popup.open(id)?;
+            InternalEvent::InspectCommit(id, tags) => {
+                self.inspect_commit_popup.open(id, tags)?;
                 flags.insert(NeedsUpdate::ALL | NeedsUpdate::COMMANDS)
             }
             InternalEvent::OpenExternalEditor(path) => {
@@ -481,6 +493,7 @@ impl App {
             || self.stashmsg_popup.is_visible()
             || self.inspect_commit_popup.is_visible()
             || self.external_editor_popup.is_visible()
+            || self.tag_commit_popup.is_visible()
     }
 
     fn draw_popups<B: Backend>(
@@ -505,6 +518,7 @@ impl App {
         self.msg.draw(f, size)?;
         self.inspect_commit_popup.draw(f, size)?;
         self.external_editor_popup.draw(f, size)?;
+        self.tag_commit_popup.draw(f, size)?;
 
         Ok(())
     }
