@@ -8,11 +8,13 @@ use crate::{
 };
 use anyhow::Result;
 use asyncgit::{
-    sync::{self, CommitDetails, CommitId, Tags},
+    sync::{self, CommitDetails, CommitId},
     CWD,
 };
 use crossterm::event::Event;
+use itertools::Itertools;
 use std::borrow::Cow;
+use sync::CommitTags;
 use tui::{
     backend::Backend,
     layout::{Constraint, Direction, Layout, Rect},
@@ -40,7 +42,7 @@ impl DetailsComponent {
     pub fn set_commit(
         &mut self,
         id: Option<CommitId>,
-        tags: &Tags,
+        tags: Option<CommitTags>,
     ) -> Result<()> {
         self.tags.clear();
 
@@ -50,10 +52,8 @@ impl DetailsComponent {
             None
         };
 
-        if let Some(id) = id {
-            if let Some(tags) = tags.get(&id) {
-                self.tags.extend(tags.clone());
-            }
+        if let Some(tags) = tags {
+            self.tags.extend(tags)
         }
 
         Ok(())
@@ -160,12 +160,20 @@ impl DetailsComponent {
                     self.theme.text(false, false),
                 ));
 
-                for tag in &self.tags {
-                    res.push(Text::Styled(
-                        Cow::from(tag),
-                        self.theme.text(true, false),
-                    ));
-                }
+                res.extend(
+                    self.tags
+                        .iter()
+                        .map(|tag| {
+                            Text::Styled(
+                                Cow::from(tag),
+                                self.theme.text(true, false),
+                            )
+                        })
+                        .intersperse(Text::Styled(
+                            Cow::from(","),
+                            self.theme.text(true, false),
+                        )),
+                );
             }
 
             res
