@@ -92,14 +92,8 @@ impl CommitList {
         self.tags.as_ref()
     }
 
-    ///
-    pub fn has_tags(&self) -> bool {
-        self.tags.is_some()
-    }
-
     ///
     pub fn clear(&mut self) {
-        self.tags = None;
         self.items.clear();
     }
 
