@@ -7,12 +7,14 @@ use crate::{
     ui::{self, style::SharedTheme},
 };
 use anyhow::{anyhow, Result};
+use asyncgit::{sync::utils::repo_work_dir, CWD};
 use crossterm::{
     event::Event,
     terminal::{EnterAlternateScreen, LeaveAlternateScreen},
     ExecutableCommand,
 };
 use scopeguard::defer;
+use std::ffi::OsStr;
 use std::{env, io, path::Path, process::Command};
 use tui::{
     backend::Backend,
@@ -38,25 +40,44 @@ impl ExternalEditorComponent {
 
     /// opens file at given `path` in an available editor
     pub fn open_file_in_editor(path: &Path) -> Result<()> {
+        let work_dir = repo_work_dir(CWD)?;
+
+        let path = if path.is_relative() {
+            Path::new(&work_dir).join(path)
+        } else {
+            path.into()
+        };
+
+        if !path.exists() {
+            return Err(anyhow!("file not found: {:?}", path));
+        }
+
         io::stdout().execute(LeaveAlternateScreen)?;
         defer! {
             io::stdout().execute(EnterAlternateScreen).expect("reset terminal");
         }
 
-        let mut editor = env::var("GIT_EDITOR")
+        let editor = env::var("GIT_EDITOR")
             .ok()
             .or_else(|| env::var("VISUAL").ok())
             .or_else(|| env::var("EDITOR").ok())
             .unwrap_or_else(|| String::from("vi"));
-        editor.push_str(&format!(" {}", path.to_string_lossy()));
 
+        // TODO: proper handling arguments containing whitespaces
+        // This does not do the right thing if the input is `editor --something "with spaces"`
         let mut editor = editor.split_whitespace();
 
         let command = editor.next().ok_or_else(|| {
             anyhow!("unable to read editor command")
         })?;
 
+        let mut editor: Vec<&OsStr> =
+            editor.map(|s| OsStr::new(s)).collect();
+
+        editor.push(path.as_os_str());
+
         Command::new(command)
+            .current_dir(work_dir)
             .args(editor)
             .status()
             .map_err(|e| anyhow!("\"{}\": {}", command, e))?;
