@@ -1,7 +1,6 @@
 use crate::tabs::StashingOptions;
-use asyncgit::sync::CommitId;
+use asyncgit::sync::{CommitId, CommitTags};
 use bitflags::bitflags;
-use std::path::PathBuf;
 use std::{cell::RefCell, collections::VecDeque, rc::Rc};
 
 bitflags! {
@@ -48,9 +47,11 @@ pub enum InternalEvent {
     ///
     TabSwitch,
     ///
-    InspectCommit(CommitId),
+    InspectCommit(CommitId, Option<CommitTags>),
     ///
-    OpenExternalEditor(Option<Box<PathBuf>>),
+    TagCommit(CommitId),
+    ///
+    OpenExternalEditor(Option<String>),
 }
 
 ///
