@@ -18,7 +18,6 @@ use asyncgit::{
 };
 use crossbeam_channel::Sender;
 use crossterm::event::Event;
-use std::path::PathBuf;
 use tui::layout::{Constraint, Direction, Layout};
 
 ///
@@ -47,6 +46,7 @@ pub struct Status {
     git_status_workdir: AsyncStatus,
     git_status_stage: AsyncStatus,
     queue: Queue,
+    git_action_executed: bool,
 }
 
 impl DrawableComponent for Status {
@@ -131,6 +131,7 @@ impl Status {
             git_diff: AsyncDiff::new(sender.clone()),
             git_status_workdir: AsyncStatus::new(sender.clone()),
             git_status_stage: AsyncStatus::new(sender.clone()),
+            git_action_executed: false,
         }
     }
 
@@ -138,7 +139,7 @@ impl Status {
         match self.focus {
             Focus::WorkDir => self.index_wd.is_file_seleted(),
             Focus::Stage => self.index.is_file_seleted(),
-            _ => false,
+            Focus::Diff => false,
         }
     }
 
@@ -203,6 +204,8 @@ impl Status {
             ))?;
             self.git_status_stage
                 .fetch(StatusParams::new(StatusType::Stage, true))?;
+
+            self.index_wd.update()?;
         }
 
         Ok(())
@@ -230,14 +233,29 @@ impl Status {
     }
 
     fn update_status(&mut self) -> Result<()> {
-        let status = self.git_status_stage.last()?;
-        self.index.update(&status.items)?;
+        let stage_status = self.git_status_stage.last()?;
+        self.index.set_items(&stage_status.items)?;
 
-        let status = self.git_status_workdir.last()?;
-        self.index_wd.update(&status.items)?;
+        let workdir_status = self.git_status_workdir.last()?;
+        self.index_wd.set_items(&workdir_status.items)?;
 
         self.update_diff()?;
 
+        if self.git_action_executed {
+            self.git_action_executed = false;
+
+            if self.focus == Focus::WorkDir
+                && workdir_status.items.is_empty()
+                && !stage_status.items.is_empty()
+            {
+                self.switch_focus(Focus::Stage)?;
+            } else if self.focus == Focus::Stage
+                && stage_status.items.is_empty()
+            {
+                self.switch_focus(Focus::WorkDir)?;
+            }
+        }
+
         Ok(())
     }
 
@@ -270,11 +288,11 @@ impl Status {
                 {
                     self.diff.update(path, is_stage, diff)?;
                 } else {
-                    self.diff.clear()?;
+                    self.diff.clear(true)?;
                 }
             }
         } else {
-            self.diff.clear()?;
+            self.diff.clear(false)?;
         }
 
         Ok(())
@@ -370,6 +388,7 @@ impl Component for Status {
     fn event(&mut self, ev: crossterm::event::Event) -> Result<bool> {
         if self.visible {
             if event_pump(ev, self.components_mut().as_mut_slice())? {
+                self.git_action_executed = true;
                 return Ok(true);
             }
 
@@ -389,9 +408,7 @@ impl Component for Status {
                         {
                             self.queue.borrow_mut().push_back(
                                 InternalEvent::OpenExternalEditor(
-                                    Some(Box::new(PathBuf::from(
-                                        path,
-                                    ))),
+                                    Some(path),
                                 ),
                             );
                         }
